==> igniteui-react-charts-18.6.0.tgz: package/esm5/lib/igr-scatter-line-series.js <==
import { __extends } from "tslib";
import { UnknownValuePlotting_$type } from "igniteui-react-core";
import { IgrScatterBase } from "./igr-scatter-base";
import { ScatterLineSeries } from "./ScatterLineSeries";
import { ensureEnum } from "igniteui-react-core";
/**
 * Represents a IgxDataChartComponent scatter line series
*/
var IgrScatterLineSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrScatterLineSeries, _super);
    function IgrScatterLineSeries(props) {
        return _super.call(this, props) || this;
    }
    IgrScatterLineSeries.prototype.createImplementation = function () {
        return new ScatterLineSeries();
    };
    Object.defineProperty(IgrScatterLineSeries.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrScatterLineSeries.prototype, "isLineOnly", {
        /**
         * Gets whether the current series shows only line shapes.
        */
        get: function () {
            return this.i.ey;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrScatterLineSeries.prototype, "unknownValuePlotting", {
        /**
         * Determines how unknown values will be plotted on the chart.
         * Null and Double.NaN are two examples of unknown values.
        */
        get: function () {
            return this.i.zg;
        },
        set: function (v) {
            this.i.zg = ensureEnum(UnknownValuePlotting_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    return IgrScatterLineSeries;
}(IgrScatterBase));
export { IgrScatterLineSeries };

==> igniteui-react-charts-18.7.2.tgz: package/esm5/lib/igr-scatter-line-series.js <==
import { __extends } from "tslib";
import { UnknownValuePlotting_$type } from "igniteui-react-core";
import { IgrScatterBase } from "./igr-scatter-base";
import { ScatterLineSeries } from "./ScatterLineSeries";
import { ensureEnum } from "igniteui-react-core";
/**
 * Represents a IgxDataChartComponent scatter line series
*/
var IgrScatterLineSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrScatterLineSeries, _super);
    function IgrScatterLineSeries(props) {
        return _super.call(this, props) || this;
    }
    IgrScatterLineSeries.prototype.createImplementation = function () {
        return new ScatterLineSeries();
    };
    Object.defineProperty(IgrScatterLineSeries.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrScatterLineSeries.prototype, "isLineOnly", {
        /**
         * Gets whether the current series shows only line shapes.
        */
        get: function () {
            return this.i.fi;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrScatterLineSeries.prototype, "unknownValuePlotting", {
        /**
         * Determines how unknown values will be plotted on the chart.
         * Null and Double.NaN are two examples of unknown values.
        */
        get: function () {
            return this.i.ace;
        },
        set: function (v) {
            this.i.ace = ensureEnum(UnknownValuePlotting_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    return IgrScatterLineSeries;
}(IgrScatterBase));
export { IgrScatterLineSeries };
